Struct etradeTaxReturnHelper::Transaction
source · pub struct Transaction {
pub transaction_date: String,
pub gross_us: f32,
pub tax_us: f32,
pub exchange_rate_date: String,
pub exchange_rate: f32,
}Fields
transaction_date: Stringgross_us: f32tax_us: f32exchange_rate_date: Stringexchange_rate: f32Trait Implementations
sourceimpl Debug for Transaction
impl Debug for Transaction
sourceimpl PartialEq<Transaction> for Transaction
impl PartialEq<Transaction> for Transaction
sourcefn eq(&self, other: &Transaction) -> bool
fn eq(&self, other: &Transaction) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd<Transaction> for Transaction
impl PartialOrd<Transaction> for Transaction
sourcefn partial_cmp(&self, other: &Transaction) -> Option<Ordering>
fn partial_cmp(&self, other: &Transaction) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read more